

{- |
Copyright  : Will Thompson, Iñaki García Etxebarria and Jonas Platte
License    : LGPL-2.1
Maintainer : Iñaki García Etxebarria (inaki@blueleaf.cc)

'GI.Gtk.Objects.Application.Application' is a class that handles many important aspects
of a GTK+ application in a convenient fashion, without enforcing
a one-size-fits-all application model.

Currently, GtkApplication handles GTK+ initialization, application
uniqueness, session management, provides some basic scriptability and
desktop shell integration by exporting actions and menus and manages a
list of toplevel windows whose life-cycle is automatically tied to the
life-cycle of your application.

While GtkApplication works fine with plain @/GtkWindows/@, it is recommended
to use it together with 'GI.Gtk.Objects.ApplicationWindow.ApplicationWindow'.

When GDK threads are enabled, GtkApplication will acquire the GDK
lock when invoking actions that arrive from other processes.  The GDK
lock is not touched for local action invocations.  In order to have
actions invoked in a predictable context it is therefore recommended
that the GDK lock be held while invoking actions locally with
'GI.Gio.Interfaces.ActionGroup.actionGroupActivateAction'.  The same applies to actions
associated with 'GI.Gtk.Objects.ApplicationWindow.ApplicationWindow' and to the “activate” and
“open” 'GI.Gio.Objects.Application.Application' methods.

## Automatic resources ## {@/automatic/@-resources}

'GI.Gtk.Objects.Application.Application' will automatically load menus from the 'GI.Gtk.Objects.Builder.Builder'
resource located at \"gtk\/menus.ui\", relative to the application\'s
resource base path (see 'GI.Gio.Objects.Application.applicationSetResourceBasePath').  The
menu with the ID \"app-menu\" is taken as the application\'s app menu
and the menu with the ID \"menubar\" is taken as the application\'s
menubar.  Additional menus (most interesting submenus) can be named
and accessed via 'GI.Gtk.Objects.Application.applicationGetMenuById' which allows for
dynamic population of a part of the menu structure.

If the resources \"gtk\/menus-appmenu.ui\" or \"gtk\/menus-traditional.ui\" are
present then these files will be used in preference, depending on the value
of 'GI.Gtk.Objects.Application.applicationPrefersAppMenu'. If the resource \"gtk\/menus-common.ui\"
is present it will be loaded as well. This is useful for storing items that
are referenced from both \"gtk\/menus-appmenu.ui\" and
\"gtk\/menus-traditional.ui\".

It is also possible to provide the menus manually using
'GI.Gtk.Objects.Application.applicationSetAppMenu' and 'GI.Gtk.Objects.Application.applicationSetMenubar'.

'GI.Gtk.Objects.Application.Application' will also automatically setup an icon search path for
the default icon theme by appending \"icons\" to the resource base
path.  This allows your application to easily store its icons as
resources.  See 'GI.Gtk.Objects.IconTheme.iconThemeAddResourcePath' for more
information.

If there is a resource located at \"gtk\/help-overlay.ui\" which
defines a 'GI.Gtk.Objects.ShortcutsWindow.ShortcutsWindow' with ID \"help_overlay\" then GtkApplication
associates an instance of this shortcuts window with each
'GI.Gtk.Objects.ApplicationWindow.ApplicationWindow' and sets up keyboard accelerators (Control-F1
and Control-?) to open it. To create a menu item that displays the
shortcuts window, associate the item with the action win.show-help-overlay.

## A simple application ## {@/gtkapplication/@}

<https://git.gnome.org/browse/gtk+/tree/examples/bp/bloatpad.c A simple example>

GtkApplication optionally registers with a session manager
of the users session (if you set the 'GI.Gtk.Objects.Application.Application':@/register-session/@
property) and offers various functionality related to the session
life-cycle.

An application can block various ways to end the session with
the 'GI.Gtk.Objects.Application.applicationInhibit' function. Typical use cases for
this kind of inhibiting are long-running, uninterruptible operations,
such as burning a CD or performing a disk backup. The session
manager may not honor the inhibitor, but it can be expected to
inform the user about the negative consequences of ending the
session while inhibitors are present.

## See Also ## {@/seealso/@}
<https://wiki.gnome.org/HowDoI/GtkApplication HowDoI: Using GtkApplication>,
<https://developer.gnome.org/gtk3/stable/gtk-getting-started.html#id-1.2.3.3 Getting Started with GTK+: Basics>
-}

#define ENABLE_OVERLOADING (MIN_VERSION_haskell_gi_overloading(1,0,0) \
       && !defined(__HADDOCK_VERSION__))

module GI.Gtk.Objects.Application
    ( 

-- * Exported types
    Application(..)                         ,
    IsApplication                           ,
    toApplication                           ,
    noApplication                           ,


 -- * Methods
-- ** addAccelerator #method:addAccelerator#

#if ENABLE_OVERLOADING
    ApplicationAddAcceleratorMethodInfo     ,
#endif
    applicationAddAccelerator               ,


-- ** addWindow #method:addWindow#

#if ENABLE_OVERLOADING
    ApplicationAddWindowMethodInfo          ,
#endif
    applicationAddWindow                    ,


-- ** getAccelsForAction #method:getAccelsForAction#

#if ENABLE_OVERLOADING
    ApplicationGetAccelsForActionMethodInfo ,
#endif
    applicationGetAccelsForAction           ,


-- ** getActionsForAccel #method:getActionsForAccel#

#if ENABLE_OVERLOADING
    ApplicationGetActionsForAccelMethodInfo ,
#endif
    applicationGetActionsForAccel           ,


-- ** getActiveWindow #method:getActiveWindow#

#if ENABLE_OVERLOADING
    ApplicationGetActiveWindowMethodInfo    ,
#endif
    applicationGetActiveWindow              ,


-- ** getAppMenu #method:getAppMenu#

#if ENABLE_OVERLOADING
    ApplicationGetAppMenuMethodInfo         ,
#endif
    applicationGetAppMenu                   ,


-- ** getMenuById #method:getMenuById#

#if ENABLE_OVERLOADING
    ApplicationGetMenuByIdMethodInfo        ,
#endif
    applicationGetMenuById                  ,


-- ** getMenubar #method:getMenubar#

#if ENABLE_OVERLOADING
    ApplicationGetMenubarMethodInfo         ,
#endif
    applicationGetMenubar                   ,


-- ** getWindowById #method:getWindowById#

#if ENABLE_OVERLOADING
    ApplicationGetWindowByIdMethodInfo      ,
#endif
    applicationGetWindowById                ,


-- ** getWindows #method:getWindows#

#if ENABLE_OVERLOADING
    ApplicationGetWindowsMethodInfo         ,
#endif
    applicationGetWindows                   ,


-- ** inhibit #method:inhibit#

#if ENABLE_OVERLOADING
    ApplicationInhibitMethodInfo            ,
#endif
    applicationInhibit                      ,


-- ** isInhibited #method:isInhibited#

#if ENABLE_OVERLOADING
    ApplicationIsInhibitedMethodInfo        ,
#endif
    applicationIsInhibited                  ,


-- ** listActionDescriptions #method:listActionDescriptions#

#if ENABLE_OVERLOADING
    ApplicationListActionDescriptionsMethodInfo,
#endif
    applicationListActionDescriptions       ,


-- ** new #method:new#

    applicationNew                          ,


-- ** prefersAppMenu #method:prefersAppMenu#

#if ENABLE_OVERLOADING
    ApplicationPrefersAppMenuMethodInfo     ,
#endif
    applicationPrefersAppMenu               ,


-- ** removeAccelerator #method:removeAccelerator#

#if ENABLE_OVERLOADING
    ApplicationRemoveAcceleratorMethodInfo  ,
#endif
    applicationRemoveAccelerator            ,


-- ** removeWindow #method:removeWindow#

#if ENABLE_OVERLOADING
    ApplicationRemoveWindowMethodInfo       ,
#endif
    applicationRemoveWindow                 ,


-- ** setAccelsForAction #method:setAccelsForAction#

#if ENABLE_OVERLOADING
    ApplicationSetAccelsForActionMethodInfo ,
#endif
    applicationSetAccelsForAction           ,


-- ** setAppMenu #method:setAppMenu#

#if ENABLE_OVERLOADING
    ApplicationSetAppMenuMethodInfo         ,
#endif
    applicationSetAppMenu                   ,


-- ** setMenubar #method:setMenubar#

#if ENABLE_OVERLOADING
    ApplicationSetMenubarMethodInfo         ,
#endif
    applicationSetMenubar                   ,


-- ** uninhibit #method:uninhibit#

#if ENABLE_OVERLOADING
    ApplicationUninhibitMethodInfo          ,
#endif
    applicationUninhibit                    ,




 -- * Properties
-- ** activeWindow #attr:activeWindow#
{- | /No description available in the introspection data./
-}
#if ENABLE_OVERLOADING
    ApplicationActiveWindowPropertyInfo     ,
#endif
#if ENABLE_OVERLOADING
    applicationActiveWindow                 ,
#endif
    getApplicationActiveWindow              ,


-- ** appMenu #attr:appMenu#
{- | /No description available in the introspection data./
-}
#if ENABLE_OVERLOADING
    ApplicationAppMenuPropertyInfo          ,
#endif
#if ENABLE_OVERLOADING
    applicationAppMenu                      ,
#endif
    clearApplicationAppMenu                 ,
    constructApplicationAppMenu             ,
    getApplicationAppMenu                   ,
    setApplicationAppMenu                   ,


-- ** menubar #attr:menubar#
{- | /No description available in the introspection data./
-}
#if ENABLE_OVERLOADING
    ApplicationMenubarPropertyInfo          ,
#endif
#if ENABLE_OVERLOADING
    applicationMenubar                      ,
#endif
    clearApplicationMenubar                 ,
    constructApplicationMenubar             ,
    getApplicationMenubar                   ,
    setApplicationMenubar                   ,


-- ** registerSession #attr:registerSession#
{- | Set this property to 'True' to register with the session manager.

/Since: 3.4/
-}
#if ENABLE_OVERLOADING
    ApplicationRegisterSessionPropertyInfo  ,
#endif
#if ENABLE_OVERLOADING
    applicationRegisterSession              ,
#endif
    constructApplicationRegisterSession     ,
    getApplicationRegisterSession           ,
    setApplicationRegisterSession           ,


-- ** screensaverActive #attr:screensaverActive#
{- | This property is 'True' if GTK+ believes that the screensaver is
currently active. GTK+ only tracks session state (including this)
when 'GI.Gtk.Objects.Application.Application'::@/register-session/@ is set to 'True'.

Tracking the screensaver state is supported on Linux.

/Since: 3.24/
-}
#if ENABLE_OVERLOADING
    ApplicationScreensaverActivePropertyInfo,
#endif
#if ENABLE_OVERLOADING
    applicationScreensaverActive            ,
#endif
    getApplicationScreensaverActive         ,




 -- * Signals
-- ** queryEnd #signal:queryEnd#

    ApplicationQueryEndCallback             ,
#if ENABLE_OVERLOADING
    ApplicationQueryEndSignalInfo           ,
#endif
    C_ApplicationQueryEndCallback           ,
    afterApplicationQueryEnd                ,
    genClosure_ApplicationQueryEnd          ,
    mk_ApplicationQueryEndCallback          ,
    noApplicationQueryEndCallback           ,
    onApplicationQueryEnd                   ,
    wrap_ApplicationQueryEndCallback        ,


-- ** windowAdded #signal:windowAdded#

    ApplicationWindowAddedCallback          ,
#if ENABLE_OVERLOADING
    ApplicationWindowAddedSignalInfo        ,
#endif
    C_ApplicationWindowAddedCallback        ,
    afterApplicationWindowAdded             ,
    genClosure_ApplicationWindowAdded       ,
    mk_ApplicationWindowAddedCallback       ,
    noApplicationWindowAddedCallback        ,
    onApplicationWindowAdded                ,
    wrap_ApplicationWindowAddedCallback     ,


-- ** windowRemoved #signal:windowRemoved#

    ApplicationWindowRemovedCallback        ,
#if ENABLE_OVERLOADING
    ApplicationWindowRemovedSignalInfo      ,
#endif
    C_ApplicationWindowRemovedCallback      ,
    afterApplicationWindowRemoved           ,
    genClosure_ApplicationWindowRemoved     ,
    mk_ApplicationWindowRemovedCallback     ,
    noApplicationWindowRemovedCallback      ,
    onApplicationWindowRemoved              ,
    wrap_ApplicationWindowRemovedCallback   ,




    ) where

import Data.GI.Base.ShortPrelude
import qualified Data.GI.Base.ShortPrelude as SP
import qualified Data.GI.Base.Overloading as O
import qualified Prelude as P

import qualified Data.GI.Base.Attributes as GI.Attributes
import qualified Data.GI.Base.ManagedPtr as B.ManagedPtr
import qualified Data.GI.Base.GClosure as B.GClosure
import qualified Data.GI.Base.GError as B.GError
import qualified Data.GI.Base.GVariant as B.GVariant
import qualified Data.GI.Base.GValue as B.GValue
import qualified Data.GI.Base.GParamSpec as B.GParamSpec
import qualified Data.GI.Base.CallStack as B.CallStack
import qualified Data.GI.Base.Properties as B.Properties
import qualified Data.Text as T
import qualified Data.ByteString.Char8 as B
import qualified Data.Map as Map
import qualified Foreign.Ptr as FP
import qualified GHC.OverloadedLabels as OL

import qualified GI.GObject.Objects.Object as GObject.Object
import qualified GI.Gio.Flags as Gio.Flags
import qualified GI.Gio.Interfaces.ActionGroup as Gio.ActionGroup
import qualified GI.Gio.Interfaces.ActionMap as Gio.ActionMap
import qualified GI.Gio.Objects.Application as Gio.Application
import qualified GI.Gio.Objects.Menu as Gio.Menu
import qualified GI.Gio.Objects.MenuModel as Gio.MenuModel
import {-# SOURCE #-} qualified GI.Gtk.Flags as Gtk.Flags
import {-# SOURCE #-} qualified GI.Gtk.Objects.Window as Gtk.Window

-- | Memory-managed wrapper type.
newtype Application = Application (ManagedPtr Application)
foreign import ccall "gtk_application_get_type"
    c_gtk_application_get_type :: IO GType

instance GObject Application where
    gobjectType = c_gtk_application_get_type
    

-- | Type class for types which can be safely cast to `Application`, for instance with `toApplication`.
class (GObject o, O.IsDescendantOf Application o) => IsApplication o
instance (GObject o, O.IsDescendantOf Application o) => IsApplication o

instance O.HasParentTypes Application
type instance O.ParentTypes Application = '[Gio.Application.Application, GObject.Object.Object, Gio.ActionGroup.ActionGroup, Gio.ActionMap.ActionMap]

-- | Cast to `Application`, for types for which this is known to be safe. For general casts, use `Data.GI.Base.ManagedPtr.castTo`.
toApplication :: (MonadIO m, IsApplication o) => o -> m Application
toApplication = liftIO . unsafeCastTo Application

-- | A convenience alias for `Nothing` :: `Maybe` `Application`.
noApplication :: Maybe Application
noApplication = Nothing

#if ENABLE_OVERLOADING
type family ResolveApplicationMethod (t :: Symbol) (o :: *) :: * where
    ResolveApplicationMethod "actionAdded" o = Gio.ActionGroup.ActionGroupActionAddedMethodInfo
    ResolveApplicationMethod "actionEnabledChanged" o = Gio.ActionGroup.ActionGroupActionEnabledChangedMethodInfo
    ResolveApplicationMethod "actionRemoved" o = Gio.ActionGroup.ActionGroupActionRemovedMethodInfo
    ResolveApplicationMethod "actionStateChanged" o = Gio.ActionGroup.ActionGroupActionStateChangedMethodInfo
    ResolveApplicationMethod "activate" o = Gio.Application.ApplicationActivateMethodInfo
    ResolveApplicationMethod "activateAction" o = Gio.ActionGroup.ActionGroupActivateActionMethodInfo
    ResolveApplicationMethod "addAccelerator" o = ApplicationAddAcceleratorMethodInfo
    ResolveApplicationMethod "addAction" o = Gio.ActionMap.ActionMapAddActionMethodInfo
    ResolveApplicationMethod "addActionEntries" o = Gio.ActionMap.ActionMapAddActionEntriesMethodInfo
    ResolveApplicationMethod "addMainOption" o = Gio.Application.ApplicationAddMainOptionMethodInfo
    ResolveApplicationMethod "addMainOptionEntries" o = Gio.Application.ApplicationAddMainOptionEntriesMethodInfo
    ResolveApplicationMethod "addOptionGroup" o = Gio.Application.ApplicationAddOptionGroupMethodInfo
    ResolveApplicationMethod "addWindow" o = ApplicationAddWindowMethodInfo
    ResolveApplicationMethod "bindBusyProperty" o = Gio.Application.ApplicationBindBusyPropertyMethodInfo
    ResolveApplicationMethod "bindProperty" o = GObject.Object.ObjectBindPropertyMethodInfo
    ResolveApplicationMethod "bindPropertyFull" o = GObject.Object.ObjectBindPropertyFullMethodInfo
    ResolveApplicationMethod "changeActionState" o = Gio.ActionGroup.ActionGroupChangeActionStateMethodInfo
    ResolveApplicationMethod "forceFloating" o = GObject.Object.ObjectForceFloatingMethodInfo
    ResolveApplicationMethod "freezeNotify" o = GObject.Object.ObjectFreezeNotifyMethodInfo
    ResolveApplicationMethod "getv" o = GObject.Object.ObjectGetvMethodInfo
    ResolveApplicationMethod "hasAction" o = Gio.ActionGroup.ActionGroupHasActionMethodInfo
    ResolveApplicationMethod "hold" o = Gio.Application.ApplicationHoldMethodInfo
    ResolveApplicationMethod "inhibit" o = ApplicationInhibitMethodInfo
    ResolveApplicationMethod "isFloating" o = GObject.Object.ObjectIsFloatingMethodInfo
    ResolveApplicationMethod "isInhibited" o = ApplicationIsInhibitedMethodInfo
    ResolveApplicationMethod "listActionDescriptions" o = ApplicationListActionDescriptionsMethodInfo
    ResolveApplicationMethod "listActions" o = Gio.ActionGroup.ActionGroupListActionsMethodInfo
    ResolveApplicationMethod "lookupAction" o = Gio.ActionMap.ActionMapLookupActionMethodInfo
    ResolveApplicationMethod "markBusy" o = Gio.Application.ApplicationMarkBusyMethodInfo
    ResolveApplicationMethod "notify" o = GObject.Object.ObjectNotifyMethodInfo
    ResolveApplicationMethod "notifyByPspec" o = GObject.Object.ObjectNotifyByPspecMethodInfo
    ResolveApplicationMethod "open" o = Gio.Application.ApplicationOpenMethodInfo
    ResolveApplicationMethod "prefersAppMenu" o = ApplicationPrefersAppMenuMethodInfo
    ResolveApplicationMethod "queryAction" o = Gio.ActionGroup.ActionGroupQueryActionMethodInfo
    ResolveApplicationMethod "quit" o = Gio.Application.ApplicationQuitMethodInfo
    ResolveApplicationMethod "ref" o = GObject.Object.ObjectRefMethodInfo
    ResolveApplicationMethod "refSink" o = GObject.Object.ObjectRefSinkMethodInfo
    ResolveApplicationMethod "register" o = Gio.Application.ApplicationRegisterMethodInfo
    ResolveApplicationMethod "release" o = Gio.Application.ApplicationReleaseMethodInfo
    ResolveApplicationMethod "removeAccelerator" o = ApplicationRemoveAcceleratorMethodInfo
    ResolveApplicationMethod "removeAction" o = Gio.ActionMap.ActionMapRemoveActionMethodInfo
    ResolveApplicationMethod "removeWindow" o = ApplicationRemoveWindowMethodInfo
    ResolveApplicationMethod "run" o = Gio.Application.ApplicationRunMethodInfo
    ResolveApplicationMethod "runDispose" o = GObject.Object.ObjectRunDisposeMethodInfo
    ResolveApplicationMethod "sendNotification" o = Gio.Application.ApplicationSendNotificationMethodInfo
    ResolveApplicationMethod "stealData" o = GObject.Object.ObjectStealDataMethodInfo
    ResolveApplicationMethod "stealQdata" o = GObject.Object.ObjectStealQdataMethodInfo
    ResolveApplicationMethod "thawNotify" o = GObject.Object.ObjectThawNotifyMethodInfo
    ResolveApplicationMethod "unbindBusyProperty" o = Gio.Application.ApplicationUnbindBusyPropertyMethodInfo
    ResolveApplicationMethod "uninhibit" o = ApplicationUninhibitMethodInfo
    ResolveApplicationMethod "unmarkBusy" o = Gio.Application.ApplicationUnmarkBusyMethodInfo
    ResolveApplicationMethod "unref" o = GObject.Object.ObjectUnrefMethodInfo
    ResolveApplicationMethod "watchClosure" o = GObject.Object.ObjectWatchClosureMethodInfo
    ResolveApplicationMethod "withdrawNotification" o = Gio.Application.ApplicationWithdrawNotificationMethodInfo
    ResolveApplicationMethod "getAccelsForAction" o = ApplicationGetAccelsForActionMethodInfo
    ResolveApplicationMethod "getActionEnabled" o = Gio.ActionGroup.ActionGroupGetActionEnabledMethodInfo
    ResolveApplicationMethod "getActionParameterType" o = Gio.ActionGroup.ActionGroupGetActionParameterTypeMethodInfo
    ResolveApplicationMethod "getActionState" o = Gio.ActionGroup.ActionGroupGetActionStateMethodInfo
    ResolveApplicationMethod "getActionStateHint" o = Gio.ActionGroup.ActionGroupGetActionStateHintMethodInfo
    ResolveApplicationMethod "getActionStateType" o = Gio.ActionGroup.ActionGroupGetActionStateTypeMethodInfo
    ResolveApplicationMethod "getActionsForAccel" o = ApplicationGetActionsForAccelMethodInfo
    ResolveApplicationMethod "getActiveWindow" o = ApplicationGetActiveWindowMethodInfo
    ResolveApplicationMethod "getAppMenu" o = ApplicationGetAppMenuMethodInfo
    ResolveApplicationMethod "getApplicationId" o = Gio.Application.ApplicationGetApplicationIdMethodInfo
    ResolveApplicationMethod "getData" o = GObject.Object.ObjectGetDataMethodInfo
    ResolveApplicationMethod "getDbusConnection" o = Gio.Application.ApplicationGetDbusConnectionMethodInfo
    ResolveApplicationMethod "getDbusObjectPath" o = Gio.Application.ApplicationGetDbusObjectPathMethodInfo
    ResolveApplicationMethod "getFlags" o = Gio.Application.ApplicationGetFlagsMethodInfo
    ResolveApplicationMethod "getInactivityTimeout" o = Gio.Application.ApplicationGetInactivityTimeoutMethodInfo
    ResolveApplicationMethod "getIsBusy" o = Gio.Application.ApplicationGetIsBusyMethodInfo
    ResolveApplicationMethod "getIsRegistered" o = Gio.Application.ApplicationGetIsRegisteredMethodInfo
    ResolveApplicationMethod "getIsRemote" o = Gio.Application.ApplicationGetIsRemoteMethodInfo
    ResolveApplicationMethod "getMenuById" o = ApplicationGetMenuByIdMethodInfo
    ResolveApplicationMethod "getMenubar" o = ApplicationGetMenubarMethodInfo
    ResolveApplicationMethod "getProperty" o = GObject.Object.ObjectGetPropertyMethodInfo
    ResolveApplicationMethod "getQdata" o = GObject.Object.ObjectGetQdataMethodInfo
    ResolveApplicationMethod "getResourceBasePath" o = Gio.Application.ApplicationGetResourceBasePathMethodInfo
    ResolveApplicationMethod "getWindowById" o = ApplicationGetWindowByIdMethodInfo
    ResolveApplicationMethod "getWindows" o = ApplicationGetWindowsMethodInfo
    ResolveApplicationMethod "setAccelsForAction" o = ApplicationSetAccelsForActionMethodInfo
    ResolveApplicationMethod "setActionGroup" o = Gio.Application.ApplicationSetActionGroupMethodInfo
    ResolveApplicationMethod "setAppMenu" o = ApplicationSetAppMenuMethodInfo
    ResolveApplicationMethod "setApplicationId" o = Gio.Application.ApplicationSetApplicationIdMethodInfo
    ResolveApplicationMethod "setData" o = GObject.Object.ObjectSetDataMethodInfo
    ResolveApplicationMethod "setDefault" o = Gio.Application.ApplicationSetDefaultMethodInfo
    ResolveApplicationMethod "setFlags" o = Gio.Application.ApplicationSetFlagsMethodInfo
    ResolveApplicationMethod "setInactivityTimeout" o = Gio.Application.ApplicationSetInactivityTimeoutMethodInfo
    ResolveApplicationMethod "setMenubar" o = ApplicationSetMenubarMethodInfo
    ResolveApplicationMethod "setOptionContextDescription" o = Gio.Application.ApplicationSetOptionContextDescriptionMethodInfo
    ResolveApplicationMethod "setOptionContextParameterString" o = Gio.Application.ApplicationSetOptionContextParameterStringMethodInfo
    ResolveApplicationMethod "setOptionContextSummary" o = Gio.Application.ApplicationSetOptionContextSummaryMethodInfo
    ResolveApplicationMethod "setProperty" o = GObject.Object.ObjectSetPropertyMethodInfo
    ResolveApplicationMethod "setResourceBasePath" o = Gio.Application.ApplicationSetResourceBasePathMethodInfo
    ResolveApplicationMethod l o = O.MethodResolutionFailed l o

instance (info ~ ResolveApplicationMethod t Application, O.MethodInfo info Application p) => OL.IsLabel t (Application -> p) where
#if MIN_VERSION_base(4,10,0)
    fromLabel = O.overloadedMethod (O.MethodProxy :: O.MethodProxy info)
#else
    fromLabel _ = O.overloadedMethod (O.MethodProxy :: O.MethodProxy info)
#endif

#endif

-- signal Application::query-end
{- |
Emitted when the session manager is about to end the session, only
if 'GI.Gtk.Objects.Application.Application'::@/register-session/@ is 'True'. Applications can
connect to this signal and call 'GI.Gtk.Objects.Application.applicationInhibit' with
'GI.Gtk.Flags.ApplicationInhibitFlagsLogout' to delay the end of the session
until state has been saved.

/Since: 3.24.8/
-}
type ApplicationQueryEndCallback =
    IO ()

-- | A convenience synonym for @`Nothing` :: `Maybe` `ApplicationQueryEndCallback`@.
noApplicationQueryEndCallback :: Maybe ApplicationQueryEndCallback
noApplicationQueryEndCallback = Nothing

-- | Type for the callback on the (unwrapped) C side.
type C_ApplicationQueryEndCallback =
    Ptr () ->                               -- object
    Ptr () ->                               -- user_data
    IO ()

-- | Generate a function pointer callable from C code, from a `C_ApplicationQueryEndCallback`.
foreign import ccall "wrapper"
    mk_ApplicationQueryEndCallback :: C_ApplicationQueryEndCallback -> IO (FunPtr C_ApplicationQueryEndCallback)

-- | Wrap the callback into a `GClosure`.
genClosure_ApplicationQueryEnd :: MonadIO m => ApplicationQueryEndCallback -> m (GClosure C_ApplicationQueryEndCallback)
genClosure_ApplicationQueryEnd cb = liftIO $ do
    let cb' = wrap_ApplicationQueryEndCallback cb
    mk_ApplicationQueryEndCallback cb' >>= B.GClosure.newGClosure


-- | Wrap a `ApplicationQueryEndCallback` into a `C_ApplicationQueryEndCallback`.
wrap_ApplicationQueryEndCallback ::
    ApplicationQueryEndCallback ->
    C_ApplicationQueryEndCallback
wrap_ApplicationQueryEndCallback _cb _ _ = do
    _cb 


{- |
Connect a signal handler for the “@query-end@” signal, to be run before the default handler.
When <https://github.com/haskell-gi/haskell-gi/wiki/Overloading overloading> is enabled, this is equivalent to

@
'Data.GI.Base.Signals.on' application #queryEnd callback
@
-}
onApplicationQueryEnd :: (IsApplication a, MonadIO m) => a -> ApplicationQueryEndCallback -> m SignalHandlerId
onApplicationQueryEnd obj cb = liftIO $ do
    let cb' = wrap_ApplicationQueryEndCallback cb
    cb'' <- mk_ApplicationQueryEndCallback cb'
    connectSignalFunPtr obj "query-end" cb'' SignalConnectBefore

{- |
Connect a signal handler for the “@query-end@” signal, to be run after the default handler.
When <https://github.com/haskell-gi/haskell-gi/wiki/Overloading overloading> is enabled, this is equivalent to

@
'Data.GI.Base.Signals.after' application #queryEnd callback
@
-}
afterApplicationQueryEnd :: (IsApplication a, MonadIO m) => a -> ApplicationQueryEndCallback -> m SignalHandlerId
afterApplicationQueryEnd obj cb = liftIO $ do
    let cb' = wrap_ApplicationQueryEndCallback cb
    cb'' <- mk_ApplicationQueryEndCallback cb'
    connectSignalFunPtr obj "query-end" cb'' SignalConnectAfter


-- signal Application::window-added
{- |
Emitted when a 'GI.Gtk.Objects.Window.Window' is added to /@application@/ through
'GI.Gtk.Objects.Application.applicationAddWindow'.

/Since: 3.2/
-}
type ApplicationWindowAddedCallback =
    Gtk.Window.Window
    {- ^ /@window@/: the newly-added 'GI.Gtk.Objects.Window.Window' -}
    -> IO ()

-- | A convenience synonym for @`Nothing` :: `Maybe` `ApplicationWindowAddedCallback`@.
noApplicationWindowAddedCallback :: Maybe ApplicationWindowAddedCallback
noApplicationWindowAddedCallback = Nothing

-- | Type for the callback on the (unwrapped) C side.
type C_ApplicationWindowAddedCallback =
    Ptr () ->                               -- object
    Ptr Gtk.Window.Window ->
    Ptr () ->                               -- user_data
    IO ()

-- | Generate a function pointer callable from C code, from a `C_ApplicationWindowAddedCallback`.
foreign import ccall "wrapper"
    mk_ApplicationWindowAddedCallback :: C_ApplicationWindowAddedCallback -> IO (FunPtr C_ApplicationWindowAddedCallback)

-- | Wrap the callback into a `GClosure`.
genClosure_ApplicationWindowAdded :: MonadIO m => ApplicationWindowAddedCallback -> m (GClosure C_ApplicationWindowAddedCallback)
genClosure_ApplicationWindowAdded cb = liftIO $ do
    let cb' = wrap_ApplicationWindowAddedCallback cb
    mk_ApplicationWindowAddedCallback cb' >>= B.GClosure.newGClosure


-- | Wrap a `ApplicationWindowAddedCallback` into a `C_ApplicationWindowAddedCallback`.
wrap_ApplicationWindowAddedCallback ::
    ApplicationWindowAddedCallback ->
    C_ApplicationWindowAddedCallback
wrap_ApplicationWindowAddedCallback _cb _ window _ = do
    window' <- (newObject Gtk.Window.Window) window
    _cb  window'


{- |
Connect a signal handler for the “@window-added@” signal, to be run before the default handler.
When <https://github.com/haskell-gi/haskell-gi/wiki/Overloading overloading> is enabled, this is equivalent to

@
'Data.GI.Base.Signals.on' application #windowAdded callback
@
-}
onApplicationWindowAdded :: (IsApplication a, MonadIO m) => a -> ApplicationWindowAddedCallback -> m SignalHandlerId
onApplicationWindowAdded obj cb = liftIO $ do
    let cb' = wrap_ApplicationWindowAddedCallback cb
    cb'' <- mk_ApplicationWindowAddedCallback cb'
    connectSignalFunPtr obj "window-added" cb'' SignalConnectBefore

{- |
Connect a signal handler for the “@window-added@” signal, to be run after the default handler.
When <https://github.com/haskell-gi/haskell-gi/wiki/Overloading overloading> is enabled, this is equivalent to

@
'Data.GI.Base.Signals.after' application #windowAdded callback
@
-}
afterApplicationWindowAdded :: (IsApplication a, MonadIO m) => a -> ApplicationWindowAddedCallback -> m SignalHandlerId
afterApplicationWindowAdded obj cb = liftIO $ do
    let cb' = wrap_ApplicationWindowAddedCallback cb
    cb'' <- mk_ApplicationWindowAddedCallback cb'
    connectSignalFunPtr obj "window-added" cb'' SignalConnectAfter


-- signal Application::window-removed
{- |
Emitted when a 'GI.Gtk.Objects.Window.Window' is removed from /@application@/,
either as a side-effect of being destroyed or explicitly
through 'GI.Gtk.Objects.Application.applicationRemoveWindow'.

/Since: 3.2/
-}
type ApplicationWindowRemovedCallback =
    Gtk.Window.Window
    {- ^ /@window@/: the 'GI.Gtk.Objects.Window.Window' that is being removed -}
    -> IO ()

-- | A convenience synonym for @`Nothing` :: `Maybe` `ApplicationWindowRemovedCallback`@.
noApplicationWindowRemovedCallback :: Maybe ApplicationWindowRemovedCallback
noApplicationWindowRemovedCallback = Nothing

-- | Type for the callback on the (unwrapped) C side.
type C_ApplicationWindowRemovedCallback =
    Ptr () ->                               -- object
    Ptr Gtk.Window.Window ->
    Ptr () ->                               -- user_data
    IO ()

-- | Generate a function pointer callable from C code, from a `C_ApplicationWindowRemovedCallback`.
foreign import ccall "wrapper"
    mk_ApplicationWindowRemovedCallback :: C_ApplicationWindowRemovedCallback -> IO (FunPtr C_ApplicationWindowRemovedCallback)

-- | Wrap the callback into a `GClosure`.
genClosure_ApplicationWindowRemoved :: MonadIO m => ApplicationWindowRemovedCallback -> m (GClosure C_ApplicationWindowRemovedCallback)
genClosure_ApplicationWindowRemoved cb = liftIO $ do
    let cb' = wrap_ApplicationWindowRemovedCallback cb
    mk_ApplicationWindowRemovedCallback cb' >>= B.GClosure.newGClosure


-- | Wrap a `ApplicationWindowRemovedCallback` into a `C_ApplicationWindowRemovedCallback`.
wrap_ApplicationWindowRemovedCallback ::
    ApplicationWindowRemovedCallback ->
    C_ApplicationWindowRemovedCallback
wrap_ApplicationWindowRemovedCallback _cb _ window _ = do
    window' <- (newObject Gtk.Window.Window) window
    _cb  window'


{- |
Connect a signal handler for the “@window-removed@” signal, to be run before the default handler.
When <https://github.com/haskell-gi/haskell-gi/wiki/Overloading overloading> is enabled, this is equivalent to

@
'Data.GI.Base.Signals.on' application #windowRemoved callback
@
-}
onApplicationWindowRemoved :: (IsApplication a, MonadIO m) => a -> ApplicationWindowRemovedCallback -> m SignalHandlerId
onApplicationWindowRemoved obj cb = liftIO $ do
    let cb' = wrap_ApplicationWindowRemovedCallback cb
    cb'' <- mk_ApplicationWindowRemovedCallback cb'
    connectSignalFunPtr obj "window-removed" cb'' SignalConnectBefore

{- |
Connect a signal handler for the “@window-removed@” signal, to be run after the default handler.
When <https://github.com/haskell-gi/haskell-gi/wiki/Overloading overloading> is enabled, this is equivalent to

@
'Data.GI.Base.Signals.after' application #windowRemoved callback
@
-}
afterApplicationWindowRemoved :: (IsApplication a, MonadIO m) => a -> ApplicationWindowRemovedCallback -> m SignalHandlerId
afterApplicationWindowRemoved obj cb = liftIO $ do
    let cb' = wrap_ApplicationWindowRemovedCallback cb
    cb'' <- mk_ApplicationWindowRemovedCallback cb'
    connectSignalFunPtr obj "window-removed" cb'' SignalConnectAfter


-- VVV Prop "active-window"
   -- Type: TInterface (Name {namespace = "Gtk", name = "Window"})
   -- Flags: [PropertyReadable]
   -- Nullable: (Just True,Nothing)

{- |
Get the value of the “@active-window@” property.
When <https://github.com/haskell-gi/haskell-gi/wiki/Overloading overloading> is enabled, this is equivalent to

@
'Data.GI.Base.Attributes.get' application #activeWindow
@
-}
getApplicationActiveWindow :: (MonadIO m, IsApplication o) => o -> m (Maybe Gtk.Window.Window)
getApplicationActiveWindow obj = liftIO $ B.Properties.getObjectPropertyObject obj "active-window" Gtk.Window.Window

#if ENABLE_OVERLOADING
data ApplicationActiveWindowPropertyInfo
instance AttrInfo ApplicationActiveWindowPropertyInfo where
    type AttrAllowedOps ApplicationActiveWindowPropertyInfo = '[ 'AttrGet, 'AttrClear]
    type AttrSetTypeConstraint ApplicationActiveWindowPropertyInfo = (~) ()
    type AttrBaseTypeConstraint ApplicationActiveWindowPropertyInfo = IsApplication
    type AttrGetType ApplicationActiveWindowPropertyInfo = (Maybe Gtk.Window.Window)
    type AttrLabel ApplicationActiveWindowPropertyInfo = "active-window"
    type AttrOrigin ApplicationActiveWindowPropertyInfo = Application
    attrGet _ = getApplicationActiveWindow
    attrSet _ = undefined
    attrConstruct _ = undefined
    attrClear _ = undefined
#endif

-- VVV Prop "app-menu"
   -- Type: TInterface (Name {namespace = "Gio", name = "MenuModel"})
   -- Flags: [PropertyReadable,PropertyWritable]
   -- Nullable: (Just True,Just True)

{- |
Get the value of the “@app-menu@” property.
When <https://github.com/haskell-gi/haskell-gi/wiki/Overloading overloading> is enabled, this is equivalent to

@
'Data.GI.Base.Attributes.get' application #appMenu
@
-}
getApplicationAppMenu :: (MonadIO m, IsApplication o) => o -> m (Maybe Gio.MenuModel.MenuModel)
getApplicationAppMenu obj = liftIO $ B.Properties.getObjectPropertyObject obj "app-menu" Gio.MenuModel.MenuModel

{- |
Set the value of the “@app-menu@” property.
When <https://github.com/haskell-gi/haskell-gi/wiki/Overloading overloading> is enabled, this is equivalent to

@
'Data.GI.Base.Attributes.set' application [ #appMenu 'Data.GI.Base.Attributes.:=' value ]
@
-}
setApplicationAppMenu :: (MonadIO m, IsApplication o, Gio.MenuModel.IsMenuModel a) => o -> a -> m ()
setApplicationAppMenu obj val = liftIO $ B.Properties.setObjectPropertyObject obj "app-menu" (Just val)

{- |
Construct a `GValueConstruct` with valid value for the “@app-menu@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
-}
constructApplicationAppMenu :: (IsApplication o, Gio.MenuModel.IsMenuModel a) => a -> IO (GValueConstruct o)
constructApplicationAppMenu val = B.Properties.constructObjectPropertyObject "app-menu" (Just val)

{- |
Set the value of the “@app-menu@” property to `Nothing`.
When <https://github.com/haskell-gi/haskell-gi/wiki/Overloading overloading> is enabled, this is equivalent to

@
'Data.GI.Base.Attributes.clear' #appMenu
@
-}
clearApplicationAppMenu :: (MonadIO m, IsApplication o) => o -> m ()
clearApplicationAppMenu obj = liftIO $ B.Properties.setObjectPropertyObject obj "app-menu" (Nothing :: Maybe Gio.MenuModel.MenuModel)

#if ENABLE_OVERLOADING
data ApplicationAppMenuPropertyInfo
instance AttrInfo ApplicationAppMenuPropertyInfo where
    type AttrAllowedOps ApplicationAppMenuPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrClear]
    type AttrSetTypeConstraint ApplicationAppMenuPropertyInfo = Gio.MenuModel.IsMenuModel
    type AttrBaseTypeConstraint ApplicationAppMenuPropertyInfo = IsApplication
    type AttrGetType ApplicationAppMenuPropertyInfo = (Maybe Gio.MenuModel.MenuModel)
    type AttrLabel ApplicationAppMenuPropertyInfo = "app-menu"
    type AttrOrigin ApplicationAppMenuPropertyInfo = Application
    attrGet _ = getApplicationAppMenu
    attrSet _ = setApplicationAppMenu
    attrConstruct _ = constructApplicationAppMenu
    attrClear _ = clearApplicationAppMenu
#endif

-- VVV Prop "menubar"
   -- Type: TInterface (Name {namespace = "Gio", name = "MenuModel"})
   -- Flags: [PropertyReadable,PropertyWritable]
   -- Nullable: (Just False,Just True)

{- |
Get the value of the “@menubar@” property.
When <https://github.com/haskell-gi/haskell-gi/wiki/Overloading overloading> is enabled, this is equivalent to

@
'Data.GI.Base.Attributes.get' application #menubar
@
-}
getApplicationMenubar :: (MonadIO m, IsApplication o) => o -> m Gio.MenuModel.MenuModel
getApplicationMenubar obj = liftIO $ checkUnexpectedNothing "getApplicationMenubar" $ B.Properties.getObjectPropertyObject obj "menubar" Gio.MenuModel.MenuModel

{- |
Set the value of the “@menubar@” property.
When <https://github.com/haskell-gi/haskell-gi/wiki/Overloading overloading> is enabled, this is equivalent to

@
'Data.GI.Base.Attributes.set' application [ #menubar 'Data.GI.Base.Attributes.:=' value ]
@
-}
setApplicationMenubar :: (MonadIO m, IsApplication o, Gio.MenuModel.IsMenuModel a) => o -> a -> m ()
setApplicationMenubar obj val = liftIO $ B.Properties.setObjectPropertyObject obj "menubar" (Just val)

{- |
Construct a `GValueConstruct` with valid value for the “@menubar@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
-}
constructApplicationMenubar :: (IsApplication o, Gio.MenuModel.IsMenuModel a) => a -> IO (GValueConstruct o)
constructApplicationMenubar val = B.Properties.constructObjectPropertyObject "menubar" (Just val)

{- |
Set the value of the “@menubar@” property to `Nothing`.
When <https://github.com/haskell-gi/haskell-gi/wiki/Overloading overloading> is enabled, this is equivalent to

@
'Data.GI.Base.Attributes.clear' #menubar
@
-}
clearApplicationMenubar :: (MonadIO m, IsApplication o) => o -> m ()
clearApplicationMenubar obj = liftIO $ B.Properties.setObjectPropertyObject obj "menubar" (Nothing :: Maybe Gio.MenuModel.MenuModel)

#if ENABLE_OVERLOADING
data ApplicationMenubarPropertyInfo
instance AttrInfo ApplicationMenubarPropertyInfo where
    type AttrAllowedOps ApplicationMenubarPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrClear]
    type AttrSetTypeConstraint ApplicationMenubarPropertyInfo = Gio.MenuModel.IsMenuModel
    type AttrBaseTypeConstraint ApplicationMenubarPropertyInfo = IsApplication
    type AttrGetType ApplicationMenubarPropertyInfo = Gio.MenuModel.MenuModel
    type AttrLabel ApplicationMenubarPropertyInfo = "menubar"
    type AttrOrigin ApplicationMenubarPropertyInfo = Application
    attrGet _ = getApplicationMenubar
    attrSet _ = setApplicationMenubar
    attrConstruct _ = constructApplicationMenubar
    attrClear _ = clearApplicationMenubar
#endif

-- VVV Prop "register-session"
   -- Type: TBasicType TBoolean
   -- Flags: [PropertyReadable,PropertyWritable]
   -- Nullable: (Nothing,Nothing)

{- |
Get the value of the “@register-session@” property.
When <https://github.com/haskell-gi/haskell-gi/wiki/Overloading overloading> is enabled, this is equivalent to

@
'Data.GI.Base.Attributes.get' application #registerSession
@
-}
getApplicationRegisterSession :: (MonadIO m, IsApplication o) => o -> m Bool
getApplicationRegisterSession obj = liftIO $ B.Properties.getObjectPropertyBool obj "register-session"

{- |
Set the value of the “@register-session@” property.
When <https://github.com/haskell-gi/haskell-gi/wiki/Overloading overloading> is enabled, this is equivalent to

@
'Data.GI.Base.Attributes.set' application [ #registerSession 'Data.GI.Base.Attributes.:=' value ]
@
-}
setApplicationRegisterSession :: (MonadIO m, IsApplication o) => o -> Bool -> m ()
setApplicationRegisterSession obj val = liftIO $ B.Properties.setObjectPropertyBool obj "register-session" val

{- |
Construct a `GValueConstruct` with valid value for the “@register-session@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
-}
constructApplicationRegisterSession :: (IsApplication o) => Bool -> IO (GValueConstruct o)
constructApplicationRegisterSession val = B.Properties.constructObjectPropertyBool "register-session" val

#if ENABLE_OVERLOADING
data ApplicationRegisterSessionPropertyInfo
instance AttrInfo ApplicationRegisterSessionPropertyInfo where
    type AttrAllowedOps ApplicationRegisterSessionPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
    type AttrSetTypeConstraint ApplicationRegisterSessionPropertyInfo = (~) Bool
    type AttrBaseTypeConstraint ApplicationRegisterSessionPropertyInfo = IsApplication
    type AttrGetType ApplicationRegisterSessionPropertyInfo = Bool
    type AttrLabel ApplicationRegisterSessionPropertyInfo = "register-session"
    type AttrOrigin ApplicationRegisterSessionPropertyInfo = Application
    attrGet _ = getApplicationRegisterSession
    attrSet _ = setApplicationRegisterSession
    attrConstruct _ = constructApplicationRegisterSession
    attrClear _ = undefined
#endif

-- VVV Prop "screensaver-active"
   -- Type: TBasicType TBoolean
   -- Flags: [PropertyReadable]
   -- Nullable: (Nothing,Nothing)

{- |
Get the value of the “@screensaver-active@” property.
When <https://github.com/haskell-gi/haskell-gi/wiki/Overloading overloading> is enabled, this is equivalent to

@
'Data.GI.Base.Attributes.get' application #screensaverActive
@
-}
getApplicationScreensaverActive :: (MonadIO m, IsApplication o) => o -> m Bool
getApplicationScreensaverActive obj = liftIO $ B.Properties.getObjectPropertyBool obj "screensaver-active"

#if ENABLE_OVERLOADING
data ApplicationScreensaverActivePropertyInfo
instance AttrInfo ApplicationScreensaverActivePropertyInfo where
    type AttrAllowedOps ApplicationScreensaverActivePropertyInfo = '[ 'AttrGet]
    type AttrSetTypeConstraint ApplicationScreensaverActivePropertyInfo = (~) ()
    type AttrBaseTypeConstraint ApplicationScreensaverActivePropertyInfo = IsApplication
    type AttrGetType ApplicationScreensaverActivePropertyInfo = Bool
    type AttrLabel ApplicationScreensaverActivePropertyInfo = "screensaver-active"
    type AttrOrigin ApplicationScreensaverActivePropertyInfo = Application
    attrGet _ = getApplicationScreensaverActive
    attrSet _ = undefined
    attrConstruct _ = undefined
    attrClear _ = undefined
#endif

#if ENABLE_OVERLOADING
instance O.HasAttributeList Application
type instance O.AttributeList Application = ApplicationAttributeList
type ApplicationAttributeList = ('[ '("actionGroup", Gio.Application.ApplicationActionGroupPropertyInfo), '("activeWindow", ApplicationActiveWindowPropertyInfo), '("appMenu", ApplicationAppMenuPropertyInfo), '("applicationId", Gio.Application.ApplicationApplicationIdPropertyInfo), '("flags", Gio.Application.ApplicationFlagsPropertyInfo), '("inactivityTimeout", Gio.Application.ApplicationInactivityTimeoutPropertyInfo), '("isBusy", Gio.Application.ApplicationIsBusyPropertyInfo), '("isRegistered", Gio.Application.ApplicationIsRegisteredPropertyInfo), '("isRemote", Gio.Application.ApplicationIsRemotePropertyInfo), '("menubar", ApplicationMenubarPropertyInfo), '("registerSession", ApplicationRegisterSessionPropertyInfo), '("resourceBasePath", Gio.Application.ApplicationResourceBasePathPropertyInfo), '("screensaverActive", ApplicationScreensaverActivePropertyInfo)] :: [(Symbol, *)])
#endif

#if ENABLE_OVERLOADING
applicationActiveWindow :: AttrLabelProxy "activeWindow"
applicationActiveWindow = AttrLabelProxy

applicationAppMenu :: AttrLabelProxy "appMenu"
applicationAppMenu = AttrLabelProxy

applicationMenubar :: AttrLabelProxy "menubar"
applicationMenubar = AttrLabelProxy

applicationRegisterSession :: AttrLabelProxy "registerSession"
applicationRegisterSession = AttrLabelProxy

applicationScreensaverActive :: AttrLabelProxy "screensaverActive"
applicationScreensaverActive = AttrLabelProxy

#endif

#if ENABLE_OVERLOADING
data ApplicationQueryEndSignalInfo
instance SignalInfo ApplicationQueryEndSignalInfo where
    type HaskellCallbackType ApplicationQueryEndSignalInfo = ApplicationQueryEndCallback
    connectSignal _ obj cb connectMode = do
        let cb' = wrap_ApplicationQueryEndCallback cb
        cb'' <- mk_ApplicationQueryEndCallback cb'
        connectSignalFunPtr obj "query-end" cb'' connectMode

data ApplicationWindowAddedSignalInfo
instance SignalInfo ApplicationWindowAddedSignalInfo where
    type HaskellCallbackType ApplicationWindowAddedSignalInfo = ApplicationWindowAddedCallback
    connectSignal _ obj cb connectMode = do
        let cb' = wrap_ApplicationWindowAddedCallback cb
        cb'' <- mk_ApplicationWindowAddedCallback cb'
        connectSignalFunPtr obj "window-added" cb'' connectMode

data ApplicationWindowRemovedSignalInfo
instance SignalInfo ApplicationWindowRemovedSignalInfo where
    type HaskellCallbackType ApplicationWindowRemovedSignalInfo = ApplicationWindowRemovedCallback
    connectSignal _ obj cb connectMode = do
        let cb' = wrap_ApplicationWindowRemovedCallback cb
        cb'' <- mk_ApplicationWindowRemovedCallback cb'
        connectSignalFunPtr obj "window-removed" cb'' connectMode

type instance O.SignalList Application = ApplicationSignalList
type ApplicationSignalList = ('[ '("actionAdded", Gio.ActionGroup.ActionGroupActionAddedSignalInfo), '("actionEnabledChanged", Gio.ActionGroup.ActionGroupActionEnabledChangedSignalInfo), '("actionRemoved", Gio.ActionGroup.ActionGroupActionRemovedSignalInfo), '("actionStateChanged", Gio.ActionGroup.ActionGroupActionStateChangedSignalInfo), '("activate", Gio.Application.ApplicationActivateSignalInfo), '("commandLine", Gio.Application.ApplicationCommandLineSignalInfo), '("handleLocalOptions", Gio.Application.ApplicationHandleLocalOptionsSignalInfo), '("nameLost", Gio.Application.ApplicationNameLostSignalInfo), '("notify", GObject.Object.ObjectNotifySignalInfo), '("open", Gio.Application.ApplicationOpenSignalInfo), '("queryEnd", ApplicationQueryEndSignalInfo), '("shutdown", Gio.Application.ApplicationShutdownSignalInfo), '("startup", Gio.Application.ApplicationStartupSignalInfo), '("windowAdded", ApplicationWindowAddedSignalInfo), '("windowRemoved", ApplicationWindowRemovedSignalInfo)] :: [(Symbol, *)])

#endif

-- method Application::new
-- method type : Constructor
-- Args : [Arg {argCName = "application_id", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = True, argDoc = Documentation {rawDocText = Just "The application ID.", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing},Arg {argCName = "flags", argType = TInterface (Name {namespace = "Gio", name = "ApplicationFlags"}), direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "the application flags", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : Just (TInterface (Name {namespace = "Gtk", name = "Application"}))
-- throws : False
-- Skip return : False

foreign import ccall "gtk_application_new" gtk_application_new :: 
    CString ->                              -- application_id : TBasicType TUTF8
    CUInt ->                                -- flags : TInterface (Name {namespace = "Gio", name = "ApplicationFlags"})
    IO (Ptr Application)

{- |
Creates a new 'GI.Gtk.Objects.Application.Application' instance.

When using 'GI.Gtk.Objects.Application.Application', it is not necessary to call 'GI.Gtk.Functions.init'
manually. It is called as soon as the application gets registered as
the primary instance.

Concretely, 'GI.Gtk.Functions.init' is called in the default handler for the
'GI.Gio.Objects.Application.Application'::@/startup/@ signal. Therefore, 'GI.Gtk.Objects.Application.Application' subclasses should
chain up in their 'GI.Gio.Objects.Application.Application'::@/startup/@ handler before using any GTK+ API.

Note that commandline arguments are not passed to 'GI.Gtk.Functions.init'.
All GTK+ functionality that is available via commandline arguments
can also be achieved by setting suitable environment variables
such as @G_DEBUG@, so this should not be a big
problem. If you absolutely must support GTK+ commandline arguments,
you can explicitly call 'GI.Gtk.Functions.init' before creating the application
instance.

If non-'Nothing', the application ID must be valid.  See
'GI.Gio.Objects.Application.applicationIdIsValid'.

If no application ID is given then some features (most notably application
uniqueness) will be disabled. A null application ID is only allowed with
GTK+ 3.6 or later.

/Since: 3.0/
-}
applicationNew ::
    (B.CallStack.HasCallStack, MonadIO m) =>
    Maybe (T.Text)
    {- ^ /@applicationId@/: The application ID. -}
    -> [Gio.Flags.ApplicationFlags]
    {- ^ /@flags@/: the application flags -}
    -> m (Maybe Application)
    {- ^ __Returns:__ a new 'GI.Gtk.Objects.Application.Application' instance -}
applicationNew applicationId flags = liftIO $ do
    maybeApplicationId <- case applicationId of
        Nothing -> return nullPtr
        Just jApplicationId -> do
            jApplicationId' <- textToCString jApplicationId
            return jApplicationId'
    let flags' = gflagsToWord flags
    result <- gtk_application_new maybeApplicationId flags'
    maybeResult <- convertIfNonNull result $ \result' -> do
        result'' <- (wrapObject Application) result'
        return result''
    freeMem maybeApplicationId
    return maybeResult

#if ENABLE_OVERLOADING
#endif

-- method Application::add_accelerator
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "application", argType = TInterface (Name {namespace = "Gtk", name = "Application"}), direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "a #GtkApplication", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing},Arg {argCName = "accelerator", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "accelerator string", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing},Arg {argCName = "action_name", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "the name of the action to activate", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing},Arg {argCName = "parameter", argType = TVariant, direction = DirectionIn, mayBeNull = True, argDoc = Documentation {rawDocText = Just "parameter to pass when activating the action,\n  or %NULL if the action does not accept an activation parameter", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : Nothing
-- throws : False
-- Skip return : False

foreign import ccall "gtk_application_add_accelerator" gtk_application_add_accelerator :: 
    Ptr Application ->                      -- application : TInterface (Name {namespace = "Gtk", name = "Application"})
    CString ->                              -- accelerator : TBasicType TUTF8
    CString ->                              -- action_name : TBasicType TUTF8
    Ptr GVariant ->                         -- parameter : TVariant
    IO ()

{-# DEPRECATED applicationAddAccelerator ["(Since version 3.14)","Use 'GI.Gtk.Objects.Application.applicationSetAccelsForAction' instead"] #-}
{- |
Installs an accelerator that will cause the named action
to be activated when the key combination specificed by /@accelerator@/
is pressed.

/@accelerator@/ must be a string that can be parsed by 'GI.Gtk.Functions.acceleratorParse',
e.g. \"\<Primary>q\" or “\<Control>\<Alt>p”.

/@actionName@/ must be the name of an action as it would be used
in the app menu, i.e. actions that have been added to the application
are referred to with an “app.” prefix, and window-specific actions
with a “win.” prefix.

GtkApplication also extracts accelerators out of “accel” attributes
in the @/GMenuModels/@ passed to 'GI.Gtk.Objects.Application.applicationSetAppMenu' and
'GI.Gtk.Objects.Application.applicationSetMenubar', which is usually more convenient
than calling this function for each accelerator.

/Since: 3.4/
-}
applicationAddAccelerator ::
    (B.CallStack.HasCallStack, MonadIO m, IsApplication a) =>
    a
    {- ^ /@application@/: a 'GI.Gtk.Objects.Application.Application' -}
    -> T.Text
    {- ^ /@accelerator@/: accelerator string -}
    -> T.Text
    {- ^ /@actionName@/: the name of the action to activate -}
    -> Maybe (GVariant)
    {- ^ /@parameter@/: parameter to pass when activating the action,
  or 'Nothing' if the action does not accept an activation parameter -}
    -> m ()
applicationAddAccelerator application accelerator actionName parameter = liftIO $ do
    application' <- unsafeManagedPtrCastPtr application
    accelerator' <- textToCString accelerator
    actionName' <- textToCString actionName
    maybeParameter <- case parameter of
        Nothing -> return nullPtr
        Just jParameter -> do
            jParameter' <- unsafeManagedPtrGetPtr jParameter
            return jParameter'
    gtk_application_add_accelerator application' accelerator' actionName' maybeParameter
    touchManagedPtr application
    whenJust parameter touchManagedPtr
    freeMem accelerator'
    freeMem actionName'
    return ()

#if ENABLE_OVERLOADING
data ApplicationAddAcceleratorMethodInfo
instance (signature ~ (T.Text -> T.Text -> Maybe (GVariant) -> m ()), MonadIO m, IsApplication a) => O.MethodInfo ApplicationAddAcceleratorMethodInfo a signature where
    overloadedMethod _ = applicationAddAccelerator

#endif

-- method Application::add_window
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "application", argType = TInterface (Name {namespace = "Gtk", name = "Application"}), direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "a #GtkApplication", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing},Arg {argCName = "window", argType = TInterface (Name {namespace = "Gtk", name = "Window"}), direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "a #GtkWindow", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : Nothing
-- throws : False
-- Skip return : False

foreign import ccall "gtk_application_add_window" gtk_application_add_window :: 
    Ptr Application ->                      -- application : TInterface (Name {namespace = "Gtk", name = "Application"})
    Ptr Gtk.Window.Window ->                -- window : TInterface (Name {namespace = "Gtk", name = "Window"})
    IO ()

{- |
Adds a window to /@application@/.

This call can only happen after the /@application@/ has started;
typically, you should add new application windows in response
to the emission of the 'GI.Gio.Objects.Application.Application'::@/activate/@ signal.

This call is equivalent to setting the 'GI.Gtk.Objects.Window.Window':@/application/@
property of /@window@/ to /@application@/.

Normally, the connection between the application and the window
will remain until the window is destroyed, but you can explicitly
remove it with 'GI.Gtk.Objects.Application.applicationRemoveWindow'.

GTK+ will keep the /@application@/ running as long as it has
any windows.

/Since: 3.0/
-}
applicationAddWindow ::
    (B.CallStack.HasCallStack, MonadIO m, IsApplication a, Gtk.Window.IsWindow b) =>
    a
    {- ^ /@application@/: a 'GI.Gtk.Objects.Application.Application' -}
    -> b
    {- ^ /@window@/: a 'GI.Gtk.Objects.Window.Window' -}
    -> m ()
applicationAddWindow application window = liftIO $ do
    application' <- unsafeManagedPtrCastPtr application
    window' <- unsafeManagedPtrCastPtr window
    gtk_application_add_window application' window'
    touchManagedPtr application
    touchManagedPtr window
    return ()

#if ENABLE_OVERLOADING
data ApplicationAddWindowMethodInfo
instance (signature ~ (b -> m ()), MonadIO m, IsApplication a, Gtk.Window.IsWindow b) => O.MethodInfo ApplicationAddWindowMethodInfo a signature where
    overloadedMethod _ = applicationAddWindow

#endif

-- method Application::get_accels_for_action
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "application", argType = TInterface (Name {namespace = "Gtk", name = "Application"}), direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "a #GtkApplication", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing},Arg {argCName = "detailed_action_name", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "a detailed action name, specifying an action\n    and target to obtain accelerators for", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : Just (TCArray True (-1) (-1) (TBasicType TUTF8))
-- throws : False
-- Skip return : False

foreign import ccall "gtk_application_get_accels_for_action" gtk_application_get_accels_for_action :: 
    Ptr Application ->                      -- application : TInterface (Name {namespace = "Gtk", name = "Application"})
    CString ->                              -- detailed_action_name : TBasicType TUTF8
    IO (Ptr CString)

{- |
Gets the accelerators that are currently associated with
the given action.

/Since: 3.12/
-}
applicationGetAccelsForAction ::
    (B.CallStack.HasCallStack, MonadIO m, IsApplication a) =>
    a
    {- ^ /@application@/: a 'GI.Gtk.Objects.Application.Application' -}
    -> T.Text
    {- ^ /@detailedActionName@/: a detailed action name, specifying an action
    and target to obtain accelerators for -}
    -> m [T.Text]
    {- ^ __Returns:__ accelerators for /@detailedActionName@/, as
    a 'Nothing'-terminated array. Free with 'GI.GLib.Functions.strfreev' when no longer needed -}
applicationGetAccelsForAction application detailedActionName = liftIO $ do
    application' <- unsafeManagedPtrCastPtr application
    detailedActionName' <- textToCString detailedActionName
    result <- gtk_application_get_accels_for_action application' detailedActionName'
    checkUnexpectedReturnNULL "applicationGetAccelsForAction" result
    result' <- unpackZeroTerminatedUTF8CArray result
    mapZeroTerminatedCArray freeMem result
    freeMem result
    touchManagedPtr application
    freeMem detailedActionName'
    return result'

#if ENABLE_OVERLOADING
data ApplicationGetAccelsForActionMethodInfo
instance (signature ~ (T.Text -> m [T.Text]), MonadIO m, IsApplication a) => O.MethodInfo ApplicationGetAccelsForActionMethodInfo a signature where
    overloadedMethod _ = applicationGetAccelsForAction

#endif

-- method Application::get_actions_for_accel
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "application", argType = TInterface (Name {namespace = "Gtk", name = "Application"}), direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "a #GtkApplication", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing},Arg {argCName = "accel", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "an accelerator that can be parsed by gtk_accelerator_parse()", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : Just (TCArray True (-1) (-1) (TBasicType TUTF8))
-- throws : False
-- Skip return : False

foreign import ccall "gtk_application_get_actions_for_accel" gtk_application_get_actions_for_accel :: 
    Ptr Application ->                      -- application : TInterface (Name {namespace = "Gtk", name = "Application"})
    CString ->                              -- accel : TBasicType TUTF8
    IO (Ptr CString)

{- |
Returns the list of actions (possibly empty) that /@accel@/ maps to.
Each item in the list is a detailed action name in the usual form.

This might be useful to discover if an accel already exists in
order to prevent installation of a conflicting accelerator (from
an accelerator editor or a plugin system, for example). Note that
having more than one action per accelerator may not be a bad thing
and might make sense in cases where the actions never appear in the
same context.

In case there are no actions for a given accelerator, an empty array
is returned.  'Nothing' is never returned.

It is a programmer error to pass an invalid accelerator string.
If you are unsure, check it with 'GI.Gtk.Functions.acceleratorParse' first.

/Since: 3.14/
-}
applicationGetActionsForAccel ::
    (B.CallStack.HasCallStack, MonadIO m, IsApplication a) =>
    a
    {- ^ /@application@/: a 'GI.Gtk.Objects.Application.Application' -}
    -> T.Text
    {- ^ /@accel@/: an accelerator that can be parsed by 'GI.Gtk.Functions.acceleratorParse' -}
    -> m [T.Text]
    {- ^ __Returns:__ a 'Nothing'-terminated array of actions for /@accel@/ -}
applicationGetActionsForAccel application accel = liftIO $ do
    application' <- unsafeManagedPtrCastPtr application
    accel' <- textToCString accel
    result <- gtk_application_get_actions_for_accel application' accel'
    checkUnexpectedReturnNULL "applicationGetActionsForAccel" result
    result' <- unpackZeroTerminatedUTF8CArray result
    mapZeroTerminatedCArray freeMem result
    freeMem result
    touchManagedPtr application
    freeMem accel'
    return result'

#if ENABLE_OVERLOADING
data ApplicationGetActionsForAccelMethodInfo
instance (signature ~ (T.Text -> m [T.Text]), MonadIO m, IsApplication a) => O.MethodInfo ApplicationGetActionsForAccelMethodInfo a signature where
    overloadedMethod _ = applicationGetActionsForAccel

#endif

-- method Application::get_active_window
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "application", argType = TInterface (Name {namespace = "Gtk", name = "Application"}), direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "a #GtkApplication", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : Just (TInterface (Name {namespace = "Gtk", name = "Window"}))
-- throws : False
-- Skip return : False

foreign import ccall "gtk_application_get_active_window" gtk_application_get_active_window :: 
    Ptr Application ->                      -- application : TInterface (Name {namespace = "Gtk", name = "Application"})
    IO (Ptr Gtk.Window.Window)

{- |
Gets the “active” window for the application.

The active window is the one that was most recently focused (within
the application).  This window may not have the focus at the moment
if another application has it — this is just the most
recently-focused window within this application.

/Since: 3.6/
-}
applicationGetActiveWindow ::
    (B.CallStack.HasCallStack, MonadIO m, IsApplication a) =>
    a
    {- ^ /@application@/: a 'GI.Gtk.Objects.Application.Application' -}
    -> m (Maybe Gtk.Window.Window)
    {- ^ __Returns:__ the active window, or 'Nothing' if
  there isn\'t one. -}
applicationGetActiveWindow application = liftIO $ do
    application' <- unsafeManagedPtrCastPtr application
    result <- gtk_application_get_active_window application'
    maybeResult <- convertIfNonNull result $ \result' -> do
        result'' <- (newObject Gtk.Window.Window) result'
        return result''
    touchManagedPtr application
    return maybeResult

#if ENABLE_OVERLOADING
data ApplicationGetActiveWindowMethodInfo
instance (signature ~ (m (Maybe Gtk.Window.Window)), MonadIO m, IsApplication a) => O.MethodInfo ApplicationGetActiveWindowMethodInfo a signature where
    overloadedMethod _ = applicationGetActiveWindow

#endif

-- method Application::get_app_menu
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "application", argType = TInterface (Name {namespace = "Gtk", name = "Application"}), direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "a #GtkApplication", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : Just (TInterface (Name {namespace = "Gio", name = "MenuModel"}))
-- throws : False
-- Skip return : False

foreign import ccall "gtk_application_get_app_menu" gtk_application_get_app_menu :: 
    Ptr Application ->                      -- application : TInterface (Name {namespace = "Gtk", name = "Application"})
    IO (Ptr Gio.MenuModel.MenuModel)

{- |
Returns the menu model that has been set with
'GI.Gtk.Objects.Application.applicationSetAppMenu'.

/Since: 3.4/
-}
applicationGetAppMenu ::
    (B.CallStack.HasCallStack, MonadIO m, IsApplication a) =>
    a
    {- ^ /@application@/: a 'GI.Gtk.Objects.Application.Application' -}
    -> m (Maybe Gio.MenuModel.MenuModel)
    {- ^ __Returns:__ the application menu of /@application@/
  or 'Nothing' if no application menu has been set. -}
applicationGetAppMenu application = liftIO $ do
    application' <- unsafeManagedPtrCastPtr application
    result <- gtk_application_get_app_menu application'
    maybeResult <- convertIfNonNull result $ \result' -> do
        result'' <- (newObject Gio.MenuModel.MenuModel) result'
        return result''
    touchManagedPtr application
    return maybeResult

#if ENABLE_OVERLOADING
data ApplicationGetAppMenuMethodInfo
instance (signature ~ (m (Maybe Gio.MenuModel.MenuModel)), MonadIO m, IsApplication a) => O.MethodInfo ApplicationGetAppMenuMethodInfo a signature where
    overloadedMethod _ = applicationGetAppMenu

#endif

-- method Application::get_menu_by_id
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "application", argType = TInterface (Name {namespace = "Gtk", name = "Application"}), direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "a #GtkApplication", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing},Arg {argCName = "id", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "the id of the menu to look up", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : Just (TInterface (Name {namespace = "Gio", name = "Menu"}))
-- throws : False
-- Skip return : False

foreign import ccall "gtk_application_get_menu_by_id" gtk_application_get_menu_by_id :: 
    Ptr Application ->                      -- application : TInterface (Name {namespace = "Gtk", name = "Application"})
    CString ->                              -- id : TBasicType TUTF8
    IO (Ptr Gio.Menu.Menu)

{- |
Gets a menu from automatically loaded resources.
See [Automatic resources][automatic-resources]
for more information.

/Since: 3.14/
-}
applicationGetMenuById ::
    (B.CallStack.HasCallStack, MonadIO m, IsApplication a) =>
    a
    {- ^ /@application@/: a 'GI.Gtk.Objects.Application.Application' -}
    -> T.Text
    {- ^ /@id@/: the id of the menu to look up -}
    -> m Gio.Menu.Menu
    {- ^ __Returns:__ Gets the menu with the
    given id from the automatically loaded resources -}
applicationGetMenuById application id = liftIO $ do
    application' <- unsafeManagedPtrCastPtr application
    id' <- textToCString id
    result <- gtk_application_get_menu_by_id application' id'
    checkUnexpectedReturnNULL "applicationGetMenuById" result
    result' <- (newObject Gio.Menu.Menu) result
    touchManagedPtr application
    freeMem id'
    return result'

#if ENABLE_OVERLOADING
data ApplicationGetMenuByIdMethodInfo
instance (signature ~ (T.Text -> m Gio.Menu.Menu), MonadIO m, IsApplication a) => O.MethodInfo ApplicationGetMenuByIdMethodInfo a signature where
    overloadedMethod _ = applicationGetMenuById

#endif

-- method Application::get_menubar
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "application", argType = TInterface (Name {namespace = "Gtk", name = "Application"}), direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "a #GtkApplication", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : Just (TInterface (Name {namespace = "Gio", name = "MenuModel"}))
-- throws : False
-- Skip return : False

foreign import ccall "gtk_application_get_menubar" gtk_application_get_menubar :: 
    Ptr Application ->                      -- application : TInterface (Name {namespace = "Gtk", name = "Application"})
    IO (Ptr Gio.MenuModel.MenuModel)

{- |
Returns the menu model that has been set with
'GI.Gtk.Objects.Application.applicationSetMenubar'.

/Since: 3.4/
-}
applicationGetMenubar ::
    (B.CallStack.HasCallStack, MonadIO m, IsApplication a) =>
    a
    {- ^ /@application@/: a 'GI.Gtk.Objects.Application.Application' -}
    -> m Gio.MenuModel.MenuModel
    {- ^ __Returns:__ the menubar for windows of /@application@/ -}
applicationGetMenubar application = liftIO $ do
    application' <- unsafeManagedPtrCastPtr application
    result <- gtk_application_get_menubar application'
    checkUnexpectedReturnNULL "applicationGetMenubar" result
    result' <- (newObject Gio.MenuModel.MenuModel) result
    touchManagedPtr application
    return result'

#if ENABLE_OVERLOADING
data ApplicationGetMenubarMethodInfo
instance (signature ~ (m Gio.MenuModel.MenuModel), MonadIO m, IsApplication a) => O.MethodInfo ApplicationGetMenubarMethodInfo a signature where
    overloadedMethod _ = applicationGetMenubar

#endif

-- method Application::get_window_by_id
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "application", argType = TInterface (Name {namespace = "Gtk", name = "Application"}), direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "a #GtkApplication", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing},Arg {argCName = "id", argType = TBasicType TUInt, direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "an identifier number", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : Just (TInterface (Name {namespace = "Gtk", name = "Window"}))
-- throws : False
-- Skip return : False

foreign import ccall "gtk_application_get_window_by_id" gtk_application_get_window_by_id :: 
    Ptr Application ->                      -- application : TInterface (Name {namespace = "Gtk", name = "Application"})
    Word32 ->                               -- id : TBasicType TUInt
    IO (Ptr Gtk.Window.Window)

{- |
Returns the 'GI.Gtk.Objects.ApplicationWindow.ApplicationWindow' with the given ID.

The ID of a 'GI.Gtk.Objects.ApplicationWindow.ApplicationWindow' can be retrieved with
'GI.Gtk.Objects.ApplicationWindow.applicationWindowGetId'.

/Since: 3.6/
-}
applicationGetWindowById ::
    (B.CallStack.HasCallStack, MonadIO m, IsApplication a) =>
    a
    {- ^ /@application@/: a 'GI.Gtk.Objects.Application.Application' -}
    -> Word32
    {- ^ /@id@/: an identifier number -}
    -> m (Maybe Gtk.Window.Window)
    {- ^ __Returns:__ the window with ID /@id@/, or
  'Nothing' if there is no window with this ID -}
applicationGetWindowById application id = liftIO $ do
    application' <- unsafeManagedPtrCastPtr application
    result <- gtk_application_get_window_by_id application' id
    maybeResult <- convertIfNonNull result $ \result' -> do
        result'' <- (newObject Gtk.Window.Window) result'
        return result''
    touchManagedPtr application
    return maybeResult

#if ENABLE_OVERLOADING
data ApplicationGetWindowByIdMethodInfo
instance (signature ~ (Word32 -> m (Maybe Gtk.Window.Window)), MonadIO m, IsApplication a) => O.MethodInfo ApplicationGetWindowByIdMethodInfo a signature where
    overloadedMethod _ = applicationGetWindowById

#endif

-- method Application::get_windows
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "application", argType = TInterface (Name {namespace = "Gtk", name = "Application"}), direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "a #GtkApplication", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : Just (TGList (TInterface (Name {namespace = "Gtk", name = "Window"})))
-- throws : False
-- Skip return : False

foreign import ccall "gtk_application_get_windows" gtk_application_get_windows :: 
    Ptr Application ->                      -- application : TInterface (Name {namespace = "Gtk", name = "Application"})
    IO (Ptr (GList (Ptr Gtk.Window.Window)))

{- |
Gets a list of the @/GtkWindows/@ associated with /@application@/.

The list is sorted by most recently focused window, such that the first
element is the currently focused window. (Useful for choosing a parent
for a transient window.)

The list that is returned should not be modified in any way. It will
only remain valid until the next focus change or window creation or
deletion.

/Since: 3.0/
-}
applicationGetWindows ::
    (B.CallStack.HasCallStack, MonadIO m, IsApplication a) =>
    a
    {- ^ /@application@/: a 'GI.Gtk.Objects.Application.Application' -}
    -> m [Gtk.Window.Window]
    {- ^ __Returns:__ a 'GI.GLib.Structs.List.List' of 'GI.Gtk.Objects.Window.Window' -}
applicationGetWindows application = liftIO $ do
    application' <- unsafeManagedPtrCastPtr application
    result <- gtk_application_get_windows application'
    result' <- unpackGList result
    result'' <- mapM (newObject Gtk.Window.Window) result'
    touchManagedPtr application
    return result''

#if ENABLE_OVERLOADING
data ApplicationGetWindowsMethodInfo
instance (signature ~ (m [Gtk.Window.Window]), MonadIO m, IsApplication a) => O.MethodInfo ApplicationGetWindowsMethodInfo a signature where
    overloadedMethod _ = applicationGetWindows

#endif

-- method Application::inhibit
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "application", argType = TInterface (Name {namespace = "Gtk", name = "Application"}), direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "the #GtkApplication", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing},Arg {argCName = "window", argType = TInterface (Name {namespace = "Gtk", name = "Window"}), direction = DirectionIn, mayBeNull = True, argDoc = Documentation {rawDocText = Just "a #GtkWindow, or %NULL", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing},Arg {argCName = "flags", argType = TInterface (Name {namespace = "Gtk", name = "ApplicationInhibitFlags"}), direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "what types of actions should be inhibited", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing},Arg {argCName = "reason", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = True, argDoc = Documentation {rawDocText = Just "a short, human-readable string that explains\n    why these operations are inhibited", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : Just (TBasicType TUInt)
-- throws : False
-- Skip return : False

foreign import ccall "gtk_application_inhibit" gtk_application_inhibit :: 
    Ptr Application ->                      -- application : TInterface (Name {namespace = "Gtk", name = "Application"})
    Ptr Gtk.Window.Window ->                -- window : TInterface (Name {namespace = "Gtk", name = "Window"})
    CUInt ->                                -- flags : TInterface (Name {namespace = "Gtk", name = "ApplicationInhibitFlags"})
    CString ->                              -- reason : TBasicType TUTF8
    IO Word32

{- |
Inform the session manager that certain types of actions should be
inhibited. This is not guaranteed to work on all platforms and for
all types of actions.

Applications should invoke this method when they begin an operation
that should not be interrupted, such as creating a CD or DVD. The
types of actions that may be blocked are specified by the /@flags@/
parameter. When the application completes the operation it should
call 'GI.Gtk.Objects.Application.applicationUninhibit' to remove the inhibitor. Note that
an application can have multiple inhibitors, and all of them must
be individually removed. Inhibitors are also cleared when the
application exits.

Applications should not expect that they will always be able to block
the action. In most cases, users will be given the option to force
the action to take place.

Reasons should be short and to the point.

If /@window@/ is given, the session manager may point the user to
this window to find out more about why the action is inhibited.

/Since: 3.4/
-}
applicationInhibit ::
    (B.CallStack.HasCallStack, MonadIO m, IsApplication a, Gtk.Window.IsWindow b) =>
    a
    {- ^ /@application@/: the 'GI.Gtk.Objects.Application.Application' -}
    -> Maybe (b)
    {- ^ /@window@/: a 'GI.Gtk.Objects.Window.Window', or 'Nothing' -}
    -> [Gtk.Flags.ApplicationInhibitFlags]
    {- ^ /@flags@/: what types of actions should be inhibited -}
    -> Maybe (T.Text)
    {- ^ /@reason@/: a short, human-readable string that explains
    why these operations are inhibited -}
    -> m Word32
    {- ^ __Returns:__ A non-zero cookie that is used to uniquely identify this
    request. It should be used as an argument to 'GI.Gtk.Objects.Application.applicationUninhibit'
    in order to remove the request. If the platform does not support
    inhibiting or the request failed for some reason, 0 is returned. -}
applicationInhibit application window flags reason = liftIO $ do
    application' <- unsafeManagedPtrCastPtr application
    maybeWindow <- case window of
        Nothing -> return nullPtr
        Just jWindow -> do
            jWindow' <- unsafeManagedPtrCastPtr jWindow
            return jWindow'
    let flags' = gflagsToWord flags
    maybeReason <- case reason of
        Nothing -> return nullPtr
        Just jReason -> do
            jReason' <- textToCString jReason
            return jReason'
    result <- gtk_application_inhibit application' maybeWindow flags' maybeReason
    touchManagedPtr application
    whenJust window touchManagedPtr
    freeMem maybeReason
    return result

#if ENABLE_OVERLOADING
data ApplicationInhibitMethodInfo
instance (signature ~ (Maybe (b) -> [Gtk.Flags.ApplicationInhibitFlags] -> Maybe (T.Text) -> m Word32), MonadIO m, IsApplication a, Gtk.Window.IsWindow b) => O.MethodInfo ApplicationInhibitMethodInfo a signature where
    overloadedMethod _ = applicationInhibit

#endif

-- method Application::is_inhibited
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "application", argType = TInterface (Name {namespace = "Gtk", name = "Application"}), direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "the #GtkApplication", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing},Arg {argCName = "flags", argType = TInterface (Name {namespace = "Gtk", name = "ApplicationInhibitFlags"}), direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "what types of actions should be queried", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : Just (TBasicType TBoolean)
-- throws : False
-- Skip return : False

foreign import ccall "gtk_application_is_inhibited" gtk_application_is_inhibited :: 
    Ptr Application ->                      -- application : TInterface (Name {namespace = "Gtk", name = "Application"})
    CUInt ->                                -- flags : TInterface (Name {namespace = "Gtk", name = "ApplicationInhibitFlags"})
    IO CInt

{- |
Determines if any of the actions specified in /@flags@/ are
currently inhibited (possibly by another application).

Note that this information may not be available (for example
when the application is running in a sandbox).

/Since: 3.4/
-}
applicationIsInhibited ::
    (B.CallStack.HasCallStack, MonadIO m, IsApplication a) =>
    a
    {- ^ /@application@/: the 'GI.Gtk.Objects.Application.Application' -}
    -> [Gtk.Flags.ApplicationInhibitFlags]
    {- ^ /@flags@/: what types of actions should be queried -}
    -> m Bool
    {- ^ __Returns:__ 'True' if any of the actions specified in /@flags@/ are inhibited -}
applicationIsInhibited application flags = liftIO $ do
    application' <- unsafeManagedPtrCastPtr application
    let flags' = gflagsToWord flags
    result <- gtk_application_is_inhibited application' flags'
    let result' = (/= 0) result
    touchManagedPtr application
    return result'

#if ENABLE_OVERLOADING
data ApplicationIsInhibitedMethodInfo
instance (signature ~ ([Gtk.Flags.ApplicationInhibitFlags] -> m Bool), MonadIO m, IsApplication a) => O.MethodInfo ApplicationIsInhibitedMethodInfo a signature where
    overloadedMethod _ = applicationIsInhibited

#endif

-- method Application::list_action_descriptions
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "application", argType = TInterface (Name {namespace = "Gtk", name = "Application"}), direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "a #GtkApplication", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : Just (TCArray True (-1) (-1) (TBasicType TUTF8))
-- throws : False
-- Skip return : False

foreign import ccall "gtk_application_list_action_descriptions" gtk_application_list_action_descriptions :: 
    Ptr Application ->                      -- application : TInterface (Name {namespace = "Gtk", name = "Application"})
    IO (Ptr CString)

{- |
Lists the detailed action names which have associated accelerators.
See 'GI.Gtk.Objects.Application.applicationSetAccelsForAction'.

/Since: 3.12/
-}
applicationListActionDescriptions ::
    (B.CallStack.HasCallStack, MonadIO m, IsApplication a) =>
    a
    {- ^ /@application@/: a 'GI.Gtk.Objects.Application.Application' -}
    -> m [T.Text]
    {- ^ __Returns:__ a 'Nothing'-terminated array of strings,
    free with 'GI.GLib.Functions.strfreev' when done -}
applicationListActionDescriptions application = liftIO $ do
    application' <- unsafeManagedPtrCastPtr application
    result <- gtk_application_list_action_descriptions application'
    checkUnexpectedReturnNULL "applicationListActionDescriptions" result
    result' <- unpackZeroTerminatedUTF8CArray result
    mapZeroTerminatedCArray freeMem result
    freeMem result
    touchManagedPtr application
    return result'

#if ENABLE_OVERLOADING
data ApplicationListActionDescriptionsMethodInfo
instance (signature ~ (m [T.Text]), MonadIO m, IsApplication a) => O.MethodInfo ApplicationListActionDescriptionsMethodInfo a signature where
    overloadedMethod _ = applicationListActionDescriptions

#endif

-- method Application::prefers_app_menu
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "application", argType = TInterface (Name {namespace = "Gtk", name = "Application"}), direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "a #GtkApplication", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : Just (TBasicType TBoolean)
-- throws : False
-- Skip return : False

foreign import ccall "gtk_application_prefers_app_menu" gtk_application_prefers_app_menu :: 
    Ptr Application ->                      -- application : TInterface (Name {namespace = "Gtk", name = "Application"})
    IO CInt

{- |
Determines if the desktop environment in which the application is
running would prefer an application menu be shown.

If this function returns 'True' then the application should call
'GI.Gtk.Objects.Application.applicationSetAppMenu' with the contents of an application
menu, which will be shown by the desktop environment.  If it returns
'False' then you should consider using an alternate approach, such as
a menubar.

The value returned by this function is purely advisory and you are
free to ignore it.  If you call 'GI.Gtk.Objects.Application.applicationSetAppMenu' even
if the desktop environment doesn\'t support app menus, then a fallback
will be provided.

Applications are similarly free not to set an app menu even if the
desktop environment wants to show one.  In that case, a fallback will
also be created by the desktop environment (GNOME, for example, uses
a menu with only a \"Quit\" item in it).

The value returned by this function never changes.  Once it returns a
particular value, it is guaranteed to always return the same value.

You may only call this function after the application has been
registered and after the base startup handler has run.  You\'re most
likely to want to use this from your own startup handler.  It may
also make sense to consult this function while constructing UI (in
activate, open or an action activation handler) in order to determine
if you should show a gear menu or not.

This function will return 'False' on Mac OS and a default app menu
will be created automatically with the \"usual\" contents of that menu
typical to most Mac OS applications.  If you call
'GI.Gtk.Objects.Application.applicationSetAppMenu' anyway, then this menu will be
replaced with your own.

/Since: 3.14/
-}
applicationPrefersAppMenu ::
    (B.CallStack.HasCallStack, MonadIO m, IsApplication a) =>
    a
    {- ^ /@application@/: a 'GI.Gtk.Objects.Application.Application' -}
    -> m Bool
    {- ^ __Returns:__ 'True' if you should set an app menu -}
applicationPrefersAppMenu application = liftIO $ do
    application' <- unsafeManagedPtrCastPtr application
    result <- gtk_application_prefers_app_menu application'
    let result' = (/= 0) result
    touchManagedPtr application
    return result'

#if ENABLE_OVERLOADING
data ApplicationPrefersAppMenuMethodInfo
instance (signature ~ (m Bool), MonadIO m, IsApplication a) => O.MethodInfo ApplicationPrefersAppMenuMethodInfo a signature where
    overloadedMethod _ = applicationPrefersAppMenu

#endif

-- method Application::remove_accelerator
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "application", argType = TInterface (Name {namespace = "Gtk", name = "Application"}), direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "a #GtkApplication", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing},Arg {argCName = "action_name", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "the name of the action to activate", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing},Arg {argCName = "parameter", argType = TVariant, direction = DirectionIn, mayBeNull = True, argDoc = Documentation {rawDocText = Just "parameter to pass when activating the action,\n  or %NULL if the action does not accept an activation parameter", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : Nothing
-- throws : False
-- Skip return : False

foreign import ccall "gtk_application_remove_accelerator" gtk_application_remove_accelerator :: 
    Ptr Application ->                      -- application : TInterface (Name {namespace = "Gtk", name = "Application"})
    CString ->                              -- action_name : TBasicType TUTF8
    Ptr GVariant ->                         -- parameter : TVariant
    IO ()

{-# DEPRECATED applicationRemoveAccelerator ["(Since version 3.14)","Use 'GI.Gtk.Objects.Application.applicationSetAccelsForAction' instead"] #-}
{- |
Removes an accelerator that has been previously added
with 'GI.Gtk.Objects.Application.applicationAddAccelerator'.

/Since: 3.4/
-}
applicationRemoveAccelerator ::
    (B.CallStack.HasCallStack, MonadIO m, IsApplication a) =>
    a
    {- ^ /@application@/: a 'GI.Gtk.Objects.Application.Application' -}
    -> T.Text
    {- ^ /@actionName@/: the name of the action to activate -}
    -> Maybe (GVariant)
    {- ^ /@parameter@/: parameter to pass when activating the action,
  or 'Nothing' if the action does not accept an activation parameter -}
    -> m ()
applicationRemoveAccelerator application actionName parameter = liftIO $ do
    application' <- unsafeManagedPtrCastPtr application
    actionName' <- textToCString actionName
    maybeParameter <- case parameter of
        Nothing -> return nullPtr
        Just jParameter -> do
            jParameter' <- unsafeManagedPtrGetPtr jParameter
            return jParameter'
    gtk_application_remove_accelerator application' actionName' maybeParameter
    touchManagedPtr application
    whenJust parameter touchManagedPtr
    freeMem actionName'
    return ()

#if ENABLE_OVERLOADING
data ApplicationRemoveAcceleratorMethodInfo
instance (signature ~ (T.Text -> Maybe (GVariant) -> m ()), MonadIO m, IsApplication a) => O.MethodInfo ApplicationRemoveAcceleratorMethodInfo a signature where
    overloadedMethod _ = applicationRemoveAccelerator

#endif

-- method Application::remove_window
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "application", argType = TInterface (Name {namespace = "Gtk", name = "Application"}), direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "a #GtkApplication", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing},Arg {argCName = "window", argType = TInterface (Name {namespace = "Gtk", name = "Window"}), direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "a #GtkWindow", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : Nothing
-- throws : False
-- Skip return : False

foreign import ccall "gtk_application_remove_window" gtk_application_remove_window :: 
    Ptr Application ->                      -- application : TInterface (Name {namespace = "Gtk", name = "Application"})
    Ptr Gtk.Window.Window ->                -- window : TInterface (Name {namespace = "Gtk", name = "Window"})
    IO ()

{- |
Remove a window from /@application@/.

If /@window@/ belongs to /@application@/ then this call is equivalent to
setting the 'GI.Gtk.Objects.Window.Window':@/application/@ property of /@window@/ to
'Nothing'.

The application may stop running as a result of a call to this
function.

/Since: 3.0/
-}
applicationRemoveWindow ::
    (B.CallStack.HasCallStack, MonadIO m, IsApplication a, Gtk.Window.IsWindow b) =>
    a
    {- ^ /@application@/: a 'GI.Gtk.Objects.Application.Application' -}
    -> b
    {- ^ /@window@/: a 'GI.Gtk.Objects.Window.Window' -}
    -> m ()
applicationRemoveWindow application window = liftIO $ do
    application' <- unsafeManagedPtrCastPtr application
    window' <- unsafeManagedPtrCastPtr window
    gtk_application_remove_window application' window'
    touchManagedPtr application
    touchManagedPtr window
    return ()

#if ENABLE_OVERLOADING
data ApplicationRemoveWindowMethodInfo
instance (signature ~ (b -> m ()), MonadIO m, IsApplication a, Gtk.Window.IsWindow b) => O.MethodInfo ApplicationRemoveWindowMethodInfo a signature where
    overloadedMethod _ = applicationRemoveWindow

#endif

-- method Application::set_accels_for_action
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "application", argType = TInterface (Name {namespace = "Gtk", name = "Application"}), direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "a #GtkApplication", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing},Arg {argCName = "detailed_action_name", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "a detailed action name, specifying an action\n    and target to associate accelerators with", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing},Arg {argCName = "accels", argType = TCArray True (-1) (-1) (TBasicType TUTF8), direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "a list of accelerators in the format\n    understood by gtk_accelerator_parse()", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : Nothing
-- throws : False
-- Skip return : False

foreign import ccall "gtk_application_set_accels_for_action" gtk_application_set_accels_for_action :: 
    Ptr Application ->                      -- application : TInterface (Name {namespace = "Gtk", name = "Application"})
    CString ->                              -- detailed_action_name : TBasicType TUTF8
    Ptr CString ->                          -- accels : TCArray True (-1) (-1) (TBasicType TUTF8)
    IO ()

{- |
Sets zero or more keyboard accelerators that will trigger the
given action. The first item in /@accels@/ will be the primary
accelerator, which may be displayed in the UI.

To remove all accelerators for an action, use an empty, zero-terminated
array for /@accels@/.

For the /@detailedActionName@/, see 'GI.Gio.Functions.actionParseDetailedName' and
'GI.Gio.Functions.actionPrintDetailedName'.

/Since: 3.12/
-}
applicationSetAccelsForAction ::
    (B.CallStack.HasCallStack, MonadIO m, IsApplication a) =>
    a
    {- ^ /@application@/: a 'GI.Gtk.Objects.Application.Application' -}
    -> T.Text
    {- ^ /@detailedActionName@/: a detailed action name, specifying an action
    and target to associate accelerators with -}
    -> [T.Text]
    {- ^ /@accels@/: a list of accelerators in the format
    understood by 'GI.Gtk.Functions.acceleratorParse' -}
    -> m ()
applicationSetAccelsForAction application detailedActionName accels = liftIO $ do
    application' <- unsafeManagedPtrCastPtr application
    detailedActionName' <- textToCString detailedActionName
    accels' <- packZeroTerminatedUTF8CArray accels
    gtk_application_set_accels_for_action application' detailedActionName' accels'
    touchManagedPtr application
    freeMem detailedActionName'
    mapZeroTerminatedCArray freeMem accels'
    freeMem accels'
    return ()

#if ENABLE_OVERLOADING
data ApplicationSetAccelsForActionMethodInfo
instance (signature ~ (T.Text -> [T.Text] -> m ()), MonadIO m, IsApplication a) => O.MethodInfo ApplicationSetAccelsForActionMethodInfo a signature where
    overloadedMethod _ = applicationSetAccelsForAction

#endif

-- method Application::set_app_menu
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "application", argType = TInterface (Name {namespace = "Gtk", name = "Application"}), direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "a #GtkApplication", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing},Arg {argCName = "app_menu", argType = TInterface (Name {namespace = "Gio", name = "MenuModel"}), direction = DirectionIn, mayBeNull = True, argDoc = Documentation {rawDocText = Just "a #GMenuModel, or %NULL", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : Nothing
-- throws : False
-- Skip return : False

foreign import ccall "gtk_application_set_app_menu" gtk_application_set_app_menu :: 
    Ptr Application ->                      -- application : TInterface (Name {namespace = "Gtk", name = "Application"})
    Ptr Gio.MenuModel.MenuModel ->          -- app_menu : TInterface (Name {namespace = "Gio", name = "MenuModel"})
    IO ()

{- |
Sets or unsets the application menu for /@application@/.

This can only be done in the primary instance of the application,
after it has been registered.  'GI.Gio.Objects.Application.Application'::@/startup/@ is a good place
to call this.

The application menu is a single menu containing items that typically
impact the application as a whole, rather than acting on a specific
window or document.  For example, you would expect to see
“Preferences” or “Quit” in an application menu, but not “Save” or
“Print”.

If supported, the application menu will be rendered by the desktop
environment.

Use the base 'GI.Gio.Interfaces.ActionMap.ActionMap' interface to add actions, to respond to the user
selecting these menu items.

/Since: 3.4/
-}
applicationSetAppMenu ::
    (B.CallStack.HasCallStack, MonadIO m, IsApplication a, Gio.MenuModel.IsMenuModel b) =>
    a
    {- ^ /@application@/: a 'GI.Gtk.Objects.Application.Application' -}
    -> Maybe (b)
    {- ^ /@appMenu@/: a 'GI.Gio.Objects.MenuModel.MenuModel', or 'Nothing' -}
    -> m ()
applicationSetAppMenu application appMenu = liftIO $ do
    application' <- unsafeManagedPtrCastPtr application
    maybeAppMenu <- case appMenu of
        Nothing -> return nullPtr
        Just jAppMenu -> do
            jAppMenu' <- unsafeManagedPtrCastPtr jAppMenu
            return jAppMenu'
    gtk_application_set_app_menu application' maybeAppMenu
    touchManagedPtr application
    whenJust appMenu touchManagedPtr
    return ()

#if ENABLE_OVERLOADING
data ApplicationSetAppMenuMethodInfo
instance (signature ~ (Maybe (b) -> m ()), MonadIO m, IsApplication a, Gio.MenuModel.IsMenuModel b) => O.MethodInfo ApplicationSetAppMenuMethodInfo a signature where
    overloadedMethod _ = applicationSetAppMenu

#endif

-- method Application::set_menubar
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "application", argType = TInterface (Name {namespace = "Gtk", name = "Application"}), direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "a #GtkApplication", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing},Arg {argCName = "menubar", argType = TInterface (Name {namespace = "Gio", name = "MenuModel"}), direction = DirectionIn, mayBeNull = True, argDoc = Documentation {rawDocText = Just "a #GMenuModel, or %NULL", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : Nothing
-- throws : False
-- Skip return : False

foreign import ccall "gtk_application_set_menubar" gtk_application_set_menubar :: 
    Ptr Application ->                      -- application : TInterface (Name {namespace = "Gtk", name = "Application"})
    Ptr Gio.MenuModel.MenuModel ->          -- menubar : TInterface (Name {namespace = "Gio", name = "MenuModel"})
    IO ()

{- |
Sets or unsets the menubar for windows of /@application@/.

This is a menubar in the traditional sense.

This can only be done in the primary instance of the application,
after it has been registered.  'GI.Gio.Objects.Application.Application'::@/startup/@ is a good place
to call this.

Depending on the desktop environment, this may appear at the top of
each window, or at the top of the screen.  In some environments, if
both the application menu and the menubar are set, the application
menu will be presented as if it were the first item of the menubar.
Other environments treat the two as completely separate — for example,
the application menu may be rendered by the desktop shell while the
menubar (if set) remains in each individual window.

Use the base 'GI.Gio.Interfaces.ActionMap.ActionMap' interface to add actions, to respond to the
user selecting these menu items.

/Since: 3.4/
-}
applicationSetMenubar ::
    (B.CallStack.HasCallStack, MonadIO m, IsApplication a, Gio.MenuModel.IsMenuModel b) =>
    a
    {- ^ /@application@/: a 'GI.Gtk.Objects.Application.Application' -}
    -> Maybe (b)
    {- ^ /@menubar@/: a 'GI.Gio.Objects.MenuModel.MenuModel', or 'Nothing' -}
    -> m ()
applicationSetMenubar application menubar = liftIO $ do
    application' <- unsafeManagedPtrCastPtr application
    maybeMenubar <- case menubar of
        Nothing -> return nullPtr
        Just jMenubar -> do
            jMenubar' <- unsafeManagedPtrCastPtr jMenubar
            return jMenubar'
    gtk_application_set_menubar application' maybeMenubar
    touchManagedPtr application
    whenJust menubar touchManagedPtr
    return ()

#if ENABLE_OVERLOADING
data ApplicationSetMenubarMethodInfo
instance (signature ~ (Maybe (b) -> m ()), MonadIO m, IsApplication a, Gio.MenuModel.IsMenuModel b) => O.MethodInfo ApplicationSetMenubarMethodInfo a signature where
    overloadedMethod _ = applicationSetMenubar

#endif

-- method Application::uninhibit
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "application", argType = TInterface (Name {namespace = "Gtk", name = "Application"}), direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "the #GtkApplication", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing},Arg {argCName = "cookie", argType = TBasicType TUInt, direction = DirectionIn, mayBeNull = False, argDoc = Documentation {rawDocText = Just "a cookie that was returned by gtk_application_inhibit()", sinceVersion = Nothing}, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : Nothing
-- throws : False
-- Skip return : False

foreign import ccall "gtk_application_uninhibit" gtk_application_uninhibit :: 
    Ptr Application ->                      -- application : TInterface (Name {namespace = "Gtk", name = "Application"})
    Word32 ->                               -- cookie : TBasicType TUInt
    IO ()

{- |
Removes an inhibitor that has been established with 'GI.Gtk.Objects.Application.applicationInhibit'.
Inhibitors are also cleared when the application exits.

/Since: 3.4/
-}
applicationUninhibit ::
    (B.CallStack.HasCallStack, MonadIO m, IsApplication a) =>
    a
    {- ^ /@application@/: the 'GI.Gtk.Objects.Application.Application' -}
    -> Word32
    {- ^ /@cookie@/: a cookie that was returned by 'GI.Gtk.Objects.Application.applicationInhibit' -}
    -> m ()
applicationUninhibit application cookie = liftIO $ do
    application' <- unsafeManagedPtrCastPtr application
    gtk_application_uninhibit application' cookie
    touchManagedPtr application
    return ()

#if ENABLE_OVERLOADING
data ApplicationUninhibitMethodInfo
instance (signature ~ (Word32 -> m ()), MonadIO m, IsApplication a) => O.MethodInfo ApplicationUninhibitMethodInfo a signature where
    overloadedMethod _ = applicationUninhibit

#endif


